@@ -281,6 +281,8 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GVI_TEST_MODE);
     MAKE_SIGNAL(NV_CTRL_COLOR_SPACE);
     MAKE_SIGNAL(NV_CTRL_COLOR_RANGE);
+    MAKE_SIGNAL(NV_CTRL_CURRENT_COLOR_SPACE);
+    MAKE_SIGNAL(NV_CTRL_CURRENT_COLOR_RANGE);
     MAKE_SIGNAL(NV_CTRL_DITHERING);
     MAKE_SIGNAL(NV_CTRL_DITHERING_MODE);
     MAKE_SIGNAL(NV_CTRL_DITHERING_DEPTH);
@@ -321,6 +323,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_MULTIGPU_MASTER_POSSIBLE);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY_ID);
+    MAKE_SIGNAL(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID);
     MAKE_SIGNAL(NV_CTRL_BACKLIGHT_BRIGHTNESS);
     MAKE_SIGNAL(NV_CTRL_GPU_LOGO_BRIGHTNESS);
     MAKE_SIGNAL(NV_CTRL_GPU_SLI_LOGO_BRIGHTNESS);
@@ -333,6 +336,9 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_VIDEO_DECODER_UTILIZATION);
     MAKE_SIGNAL(NV_CTRL_GPU_OVER_VOLTAGE_OFFSET);
     MAKE_SIGNAL(NV_CTRL_GPU_CURRENT_CORE_VOLTAGE);
+    MAKE_SIGNAL(NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR);
+    MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_CURRENT_LEVEL);
+    MAKE_SIGNAL(NV_CTRL_STEREO_SWAP_MODE);
 #undef MAKE_SIGNAL
 
     /*
@@ -342,7 +348,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GPU_CURRENT_CORE_VOLTAGE
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID
 #warning "There are attributes that do not emit signals!"
 #endif
 
